@@ -948,6 +948,41 @@ class AdsAPI(object):
         }
         return self.make_request(path, 'POST', args, batch=batch)
 
+    def get_connection_objects(self, account_id,
+                               business_id=None, batch=False):
+        """
+        Returns facebook connection objects for given account
+
+        Params:
+        business_id - restrict query to particular business
+        """
+        path = 'act_{}/connectionobjects'.format(account_id)
+        args = {}
+        if business_id:
+            args['business_id'] = business_id
+
+        return self.make_request(path, 'GET', args, batch=batch)
+
+    def get_broad_targeting_categories(self, account_id,
+                                       user_adclusters=None,
+                                       excluded_user_adclusters=None,
+                                       batch=False):
+        """
+        Get broad targeting categories for the given account
+
+        Params:
+        user_adclusters - Array of ID-name pairs to include.
+        excluded_user_adclusters - Array of ID-name pairs to exclude
+        """
+        path = 'act_{}/broadtargetingcategories'.format(account_id)
+        args = {}
+        if user_adclusters:
+            args['user_adclusters'] = user_adclusters
+        if excluded_user_adclusters:
+            args['excluded_user_adclusters'] = excluded_user_adclusters
+
+        return self.make_request(path, 'GET', args, batch=batch)
+
     def __parse_time(self, time_obj):
         """Internal function to transform user supplied time objects into Unix time."""
         if time_obj:
